Module error

Module error 

Errors returned when generating code.

Enums

BuildError
Error type returned when the code generation failed for some reason.
ConfigError
Error type returned when the configuration passed to RosettaBuilder is invalid.
ParseError
Error type returned when a parsing error occurs.